==> cronus-deck-helper-2.3.8.tgz: package/lib/AgendaRules.js <==
'use strict';

function hasKeyword(card, keywordRegex) {
    var lines = card.text.split('\n');
    var keywordLine = lines[0] || '';
    var keywords = keywordLine.split('.').map(function (keyword) {
        return keyword.trim();
    }).filter(function (keyword) {
        return keyword.length !== 0;
    });

    return keywords.some(function (keyword) {
        return keywordRegex.test(keyword);
    });
}

function hasTrait(card, trait) {
    return card.traits.some(function (t) {
        return t.toLowerCase() === trait.toLowerCase();
    });
}

function rulesForBanner(faction, factionName) {
    return {
        mayInclude: function mayInclude(card) {
            return card.faction === faction && !card.loyal && card.type !== 'plot';
        },
        rules: [{
            message: 'Must contain 12 or more ' + factionName + ' cards',
            condition: function condition(deck) {
                return deck.countDrawCards(function (card) {
                    return card.faction === faction;
                }) >= 12;
            }
        }]
    };
}

/**
 * Validation rule structure is as follows. All fields are optional.
 *
 * requiredDraw  - the minimum amount of cards required for the draw deck.
 * requiredPlots - the exact number of cards required for the plot deck.
 * maxDoubledPlots - the maximum amount of plot cards that can be contained twice in the plot deck.
 * mayInclude    - function that takes a card and returns true if it is allowed in the overall deck.
 * cannotInclude - function that takes a card and return true if it is not allowed in the overall deck.
 * rules         - an array of objects containing a `condition` function that takes a deck and return true if the deck is valid for that rule, and a `message` used for errors when invalid.
 */
var agendaRules = {
    // Banner of the stag
    '01198': rulesForBanner('baratheon', 'Baratheon'),
    // Banner of the kraken
    '01199': rulesForBanner('greyjoy', 'Greyjoy'),
    // Banner of the lion
    '01200': rulesForBanner('lannister', 'Lannister'),
    // Banner of the sun
    '01201': rulesForBanner('martell', 'Martell'),
    // Banner of the watch
    '01202': rulesForBanner('thenightswatch', 'Night\'s Watch'),
    // Banner of the wolf
    '01203': rulesForBanner('stark', 'Stark'),
    // Banner of the dragon
    '01204': rulesForBanner('targaryen', 'Targaryen'),
    // Banner of the rose
    '01205': rulesForBanner('tyrell', 'Tyrell'),
    // Banner of the wei
    '295005': rulesForBanner('wei', 'Wei'),
    // Banner of the wu
    '295006': rulesForBanner('wu', 'Wu'),
    // Banner of the shu
    '295007': rulesForBanner('shu', 'Shu'),
    // Fealty
    '01027': {
        rules: [{
            message: 'You cannot include more than 15 neutral cards in a deck with Fealty',
            condition: function condition(deck) {
                return deck.countDrawCards(function (card) {
                    return card.faction === 'neutral';
                }) <= 15;
            }}
        ]
    },
    // Fealty
    '295001': {
        rules: [{
            message: 'You cannot include more than 15 neutral cards in a deck with 讨汉贼五臣死节',
            condition: function condition(deck) {
                return deck.countDrawCards(function (card) {
                    return card.faction === 'neutral';
                }) <= 15;
            }}
        ]
    },
    // Kings of Summer
    '04037': {
        cannotInclude: card => card.type === 'plot' && (hasTrait(card, 'Winter')||hasTrait(card, '寒冬')),
        rules: [
            {
                message: 'Kings of Summer cannot include Winter plot cards',
                condition: deck => !(deck.plotCards.some(cardQuantity => (hasTrait(cardQuantity.card, 'Winter')||hasTrait(cardQuantity.card, '寒冬'))))
            }
        ]
    },
    // Kings of Winter
    '04038': {
        cannotInclude: card => card.type === 'plot' && (hasTrait(card, 'Summer')||hasTrait(card, '盛夏')),
        rules: [
            {
                message: 'Kings of Winter cannot include Summer plot cards',
                condition: deck => !(deck.plotCards.some(cardQuantity => (hasTrait(cardQuantity.card, 'Summer')||hasTrait(cardQuantity.card, '盛夏'))))
            }
        ]
    },
    // Rains of Castamere
    '05045': {
        requiredPlots: 12,
        rules: [{
            message: 'Rains of Castamere must contain exactly 5 different Scheme plots',
            condition: function condition(deck) {
                var isScheme = function isScheme(card) {
                    return hasTrait(card, 'Scheme') ||hasTrait(cardQuantity.card, '诡计');
                };
                var schemePlots = deck.plotCards.filter(function (cardQuantity) {
                    return isScheme(cardQuantity.card);
                });
                return schemePlots.length === 5 && deck.countPlotCards(isScheme) === 5;
            }}
        ]
    },
    // Alliance
    '06018': {
        requiredDraw: 75,
        rules: [{
            message: 'Alliance cannot have more than 2 Banner agendas',
            condition: function condition(deck) {
                return !deck.bannerCards || deck.bannerCards.length <= 2;
            }
        }]
    },
    // The Brotherhood Without Banners
    '06119': {
        cannotInclude: function cannotInclude(card) {
            return card.type === 'character' && card.loyal;
        },
        rules: [{
            message: 'The Brotherhood Without Banners cannot include loyal characters',
            condition: function condition(deck) {
                return !deck.drawCards.some(function (cardQuantity) {
                    return cardQuantity.card.type === 'character' && cardQuantity.card.loyal;
                });
            }
        }]
    },
    // The Conclave
    '09045': {
        mayInclude: function mayInclude(card) {
            return card.type === 'character' && (hasTrait(card, 'Maester')||hasTrait(card, '学士')) && !card.loyal;
        },
        rules: [{
            message: 'Must contain 12 or more Maester characters',
            condition: function condition(deck) {
                return deck.countDrawCards(function (card) {
                    return card.type === 'character' && (hasTrait(card, 'Maester')||hasTrait(card, '学士'));
                }) >= 12;
            }}
        ]
    },
    // The Wars To Come
    '10045': {
        requiredPlots: 10,
        maxDoubledPlots: 2
    },
    // The Free Folk
    '11079': {
        cannotInclude: function cannotInclude(card) {
            return card.faction !== 'neutral';
        }
    },
    // Kingdom of Shadows
    '13079': {
        mayInclude: function mayInclude(card) {
            return !card.loyal && hasKeyword(card, /Shadow \(\d+\)/);
        }
    },
    // The White Book
    '13099': {
        mayInclude: card => card.type === 'character' && (hasTrait(card, 'Kingsguard')||hasTrait(card, '御林铁卫')) && !card.loyal,
        rules: [
            {
                message: 'Must contain 7 or more different Kingsguard characters',
                condition: deck => {
                    const kingsguardChars = deck.drawCards.filter(cardQuantity => cardQuantity.card.type === 'character' && (hasTrait(cardQuantity.card, 'Kingsguard')||hasTrait(cardQuantity.card, '御林铁卫')));
                    return kingsguardChars.length >= 7;
                }
            }
        ]
    },
    // Valyrian Steel
    '13118': {
        requiredDraw: 75,
        rules: [{
            message: 'Cannot include more than 1 copy of each attachment (by title)',
            condition: function condition(deck) {
                var allCards = deck.drawCards.concat(deck.plotCards);
                var attachmentNames = allCards.filter(function (cardQuantity) {
                    return cardQuantity.card.type === 'attachment';
                }).map(function (cardQuantity) {
                    return cardQuantity.card.name;
                });
                return attachmentNames.every(function (attachmentName) {
                    return deck.countCards(function (card) {
                        return card.name === attachmentName;
                    }) <= 1;
                });
            }
        }]
    },
    // Dark Wings, Dark Words
    '16028': {
        requiredDraw: 75,
        rules: [{
            message: 'Cannot include more than 1 copy of each event (by title)',
            condition: function condition(deck) {
                var allCards = deck.drawCards.concat(deck.plotCards);
                var eventNames = allCards.filter(function (cardQuantity) {
                    return cardQuantity.card.type === 'event';
                }).map(function (cardQuantity) {
                    return cardQuantity.card.name;
                });
                return eventNames.every(function (eventName) {
                    return deck.countCards(function (card) {
                        return card.name === eventName;
                    }) <= 1;
                });
            }
        }]
    },
    // The Long Voyage
    '16030': {
        requiredDraw: 100
    },
    // Kingdom of Shadows (Redesign)
    '17148': {
        mayInclude: card => !card.loyal && (hasKeyword(card, /Shadow \(\d+\)/)||hasKeyword(card, /暗影\(\d+\)/))
    },
    // Sea of Blood (Redesign)
    '17149': {
        cannotInclude: function cannotInclude(card) {
            return card.faction === 'neutral' && card.type === 'event';
        }
    },
    // The Free Folk (Redesign)
    '17150': {
        mayInclude: card => card.faction !== 'neutral' && card.type === 'character' && !card.loyal && (hasTrait(card, 'Wildling')||hasTrait(card, '野人')),
        rules: [{
            message: 'Must only contain neutral cards or Non-loyal Wildling characters',
            condition: function condition(deck) {
                let drawDeckValid = !deck.drawCards.some(function (cardQuantity) {
                    return cardQuantity.card.faction !== 'neutral' && !(cardQuantity.card.type === 'character' && !cardQuantity.card.loyal && (hasTrait(cardQuantity.card, 'Wildling')||hasTrait(cardQuantity.card, '野人')));
                });
                let plotDeckValid = !deck.plotCards.some(function (cardQuantity) {
                    return cardQuantity.card.faction !== 'neutral';
                });
                return drawDeckValid && plotDeckValid;
            }
        }]
    },
    // The Wars To Come (Redesign)
    '17151': {
        requiredPlots: 10,
        maxDoubledPlots: 2
    },
    // Valyrian Steel (Redesign)
    '17152': {
        requiredDraw: 75,
        rules: [{
            message: 'Cannot include more than 1 copy of each attachment',
            condition: function condition(deck) {
                var allCards = deck.drawCards.concat(deck.plotCards);
                var attachments = allCards.filter(function (cardQuantity) {
                    return cardQuantity.card.type === 'attachment';
                });
                return attachments.every(function (attachment) {
                    return attachment.count <= 1;
                });
            }
        }]
    },
    // A Mummer's Farce
    '20051': {
        mayInclude: function mayInclude(card) {
            return card.type === 'character' && (hasTrait(card, 'Fool') || hasTrait(card, '弄臣')) && !card.loyal;
        }
    },
    // The Many-Faced God
    '20052': {
        cannotInclude: function cannotInclude(card) {
            return card.type === 'plot' && (hasTrait(card, 'Kingdom')||hasTrait(card, '王国'));
        }
    },
    // Battle of the Trident
    '21030': {
        requiredPlots: 10,
        rules: [{
            message: 'Battle of the Trident must contain exactly 10 Edict, Siege or War plots',
            condition: function condition(deck) {
                return deck.plotCards.every(function (cardQuantity) {
                    return hasTrait(cardQuantity.card, 'Edict') || hasTrait(cardQuantity.card, 'Siege') || hasTrait(cardQuantity.card, 'War');
                });
            }
        }]
    },
    // Draft Agendas
    // The Power of Wealth
    '00001': {
        mayInclude: function mayInclude() {
            return true;
        },
        rules: [{
            message: 'Cannot include cards from more than 1 outside faction',
            condition: function condition(deck) {
                var outOfFactionCards = deck.drawCards.concat(deck.plotCards).filter(function (cardQuantity) {
                    return cardQuantity.card.faction !== deck.faction.value && cardQuantity.card.faction !== 'neutral';
                });
                var factions = new Set(outOfFactionCards.map(function (cardQuantity) {
                    return cardQuantity.card.faction;
                }));
                return factions.size <= 1;
            }
        }]
    },
    // Protectors of the Realm
    '00002': {
        mayInclude: function mayInclude(card) {
            return card.type === 'character' && (hasTrait(card, 'Knight') || hasTrait(card, 'Army') || hasTrait(card, '骑士') || hasTrait(card, '军队'));
        }
    },
    // Treaty
    '00003': {
        mayInclude: function mayInclude() {
            return true;
        },
        rules: [{
            message: 'Cannot include cards from more than 2 outside factions',
            condition: function condition(deck) {
                var outOfFactionCards = deck.drawCards.concat(deck.plotCards).filter(function (cardQuantity) {
                    return cardQuantity.card.faction !== deck.faction.value && cardQuantity.card.faction !== 'neutral';
                });
                var factions = new Set(outOfFactionCards.map(function (cardQuantity) {
                    return cardQuantity.card.faction;
                }));
                return factions.size <= 2;
            }
        }]
    },
    // Uniting the Seven Kingdoms
    '00004': {
        mayInclude: function mayInclude(card) {
            return card.type !== 'plot';
        }
    }
};

module.exports = agendaRules;

==> cronus-deck-helper-2.3.10.tgz: package/lib/AgendaRules.js <==
'use strict';

function hasKeyword(card, keywordRegex) {
    var lines = card.text.split('\n');
    var keywordLine = lines[0] || '';
    var keywords = keywordLine.split('.').map(function (keyword) {
        return keyword.trim();
    }).filter(function (keyword) {
        return keyword.length !== 0;
    });

    return keywords.some(function (keyword) {
        return keywordRegex.test(keyword);
    });
}

function hasTrait(card, trait) {
    return card.traits.some(function (t) {
        return t.toLowerCase() === trait.toLowerCase();
    });
}

function rulesForBanner(faction, factionName) {
    return {
        mayInclude: function mayInclude(card) {
            return card.faction === faction && !card.loyal && card.type !== 'plot';
        },
        rules: [{
            message: 'Must contain 12 or more ' + factionName + ' cards',
            condition: function condition(deck) {
                return deck.countDrawCards(function (card) {
                    return card.faction === faction;
                }) >= 12;
            }
        }]
    };
}

/**
 * Validation rule structure is as follows. All fields are optional.
 *
 * requiredDraw  - the minimum amount of cards required for the draw deck.
 * requiredPlots - the exact number of cards required for the plot deck.
 * maxDoubledPlots - the maximum amount of plot cards that can be contained twice in the plot deck.
 * mayInclude    - function that takes a card and returns true if it is allowed in the overall deck.
 * cannotInclude - function that takes a card and return true if it is not allowed in the overall deck.
 * rules         - an array of objects containing a `condition` function that takes a deck and return true if the deck is valid for that rule, and a `message` used for errors when invalid.
 */
var agendaRules = {
    // Banner of the stag
    '01198': rulesForBanner('baratheon', 'Baratheon'),
    // Banner of the kraken
    '01199': rulesForBanner('greyjoy', 'Greyjoy'),
    // Banner of the lion
    '01200': rulesForBanner('lannister', 'Lannister'),
    // Banner of the sun
    '01201': rulesForBanner('martell', 'Martell'),
    // Banner of the watch
    '01202': rulesForBanner('thenightswatch', 'Night\'s Watch'),
    // Banner of the wolf
    '01203': rulesForBanner('stark', 'Stark'),
    // Banner of the dragon
    '01204': rulesForBanner('targaryen', 'Targaryen'),
    // Banner of the rose
    '01205': rulesForBanner('tyrell', 'Tyrell'),
    // Banner of the wei
    '295005': rulesForBanner('wei', 'Wei'),
    // Banner of the wu
    '295006': rulesForBanner('wu', 'Wu'),
    // Banner of the shu
    '295007': rulesForBanner('shu', 'Shu'),
    // Fealty
    '01027': {
        rules: [{
            message: 'You cannot include more than 15 neutral cards in a deck with Fealty',
            condition: function condition(deck) {
                return deck.countDrawCards(function (card) {
                    return card.faction === 'neutral';
                }) <= 15;
            }}
        ]
    },
    // Fealty
    '295001': {
        rules: [{
            message: 'You cannot include more than 15 neutral cards in a deck with 讨汉贼五臣死节',
            condition: function condition(deck) {
                return deck.countDrawCards(function (card) {
                    return card.faction === 'neutral';
                }) <= 15;
            }}
        ]
    },
    // Kings of Summer
    '04037': {
        cannotInclude: card => card.type === 'plot' && (hasTrait(card, 'Winter')||hasTrait(card, '寒冬')),
        rules: [
            {
                message: 'Kings of Summer cannot include Winter plot cards',
                condition: deck => !(deck.plotCards.some(cardQuantity => (hasTrait(cardQuantity.card, 'Winter')||hasTrait(cardQuantity.card, '寒冬'))))
            }
        ]
    },
    // Kings of Winter
    '04038': {
        cannotInclude: card => card.type === 'plot' && (hasTrait(card, 'Summer')||hasTrait(card, '盛夏')),
        rules: [
            {
                message: 'Kings of Winter cannot include Summer plot cards',
                condition: deck => !(deck.plotCards.some(cardQuantity => (hasTrait(cardQuantity.card, 'Summer')||hasTrait(cardQuantity.card, '盛夏'))))
            }
        ]
    },
    // Rains of Castamere
    '05045': {
        requiredPlots: 12,
        rules: [{
            message: 'Rains of Castamere must contain exactly 5 different Scheme plots',
            condition: function condition(deck) {
                var isScheme = function isScheme(card) {
                    return hasTrait(card, 'Scheme') ||hasTrait(card, '诡计');
                };
                var schemePlots = deck.plotCards.filter(function (cardQuantity) {
                    return isScheme(cardQuantity.card);
                });
                return schemePlots.length === 5 && deck.countPlotCards(isScheme) === 5;
            }}
        ]
    },
    // Alliance
    '06018': {
        requiredDraw: 75,
        rules: [{
            message: 'Alliance cannot have more than 2 Banner agendas',
            condition: function condition(deck) {
                return !deck.bannerCards || deck.bannerCards.length <= 2;
            }
        }]
    },
    // The Brotherhood Without Banners
    '06119': {
        cannotInclude: function cannotInclude(card) {
            return card.type === 'character' && card.loyal;
        },
        rules: [{
            message: 'The Brotherhood Without Banners cannot include loyal characters',
            condition: function condition(deck) {
                return !deck.drawCards.some(function (cardQuantity) {
                    return cardQuantity.card.type === 'character' && cardQuantity.card.loyal;
                });
            }
        }]
    },
    // The Conclave
    '09045': {
        mayInclude: function mayInclude(card) {
            return card.type === 'character' && (hasTrait(card, 'Maester')||hasTrait(card, '学士')) && !card.loyal;
        },
        rules: [{
            message: 'Must contain 12 or more Maester characters',
            condition: function condition(deck) {
                return deck.countDrawCards(function (card) {
                    return card.type === 'character' && (hasTrait(card, 'Maester')||hasTrait(card, '学士'));
                }) >= 12;
            }}
        ]
    },
    // The Wars To Come
    '10045': {
        requiredPlots: 10,
        maxDoubledPlots: 2
    },
    // The Free Folk
    '11079': {
        cannotInclude: function cannotInclude(card) {
            return card.faction !== 'neutral';
        }
    },
    // Kingdom of Shadows
    '13079': {
        mayInclude: function mayInclude(card) {
            return !card.loyal && hasKeyword(card, /Shadow \(\d+\)/);
        }
    },
    // The White Book
    '13099': {
        mayInclude: card => card.type === 'character' && (hasTrait(card, 'Kingsguard')||hasTrait(card, '御林铁卫')) && !card.loyal,
        rules: [
            {
                message: 'Must contain 7 or more different Kingsguard characters',
                condition: deck => {
                    const kingsguardChars = deck.drawCards.filter(cardQuantity => cardQuantity.card.type === 'character' && (hasTrait(cardQuantity.card, 'Kingsguard')||hasTrait(cardQuantity.card, '御林铁卫')));
                    return kingsguardChars.length >= 7;
                }
            }
        ]
    },
    // Valyrian Steel
    '13118': {
        requiredDraw: 75,
        rules: [{
            message: 'Cannot include more than 1 copy of each attachment (by title)',
            condition: function condition(deck) {
                var allCards = deck.drawCards.concat(deck.plotCards);
                var attachmentNames = allCards.filter(function (cardQuantity) {
                    return cardQuantity.card.type === 'attachment';
                }).map(function (cardQuantity) {
                    return cardQuantity.card.name;
                });
                return attachmentNames.every(function (attachmentName) {
                    return deck.countCards(function (card) {
                        return card.name === attachmentName;
                    }) <= 1;
                });
            }
        }]
    },
    // Dark Wings, Dark Words
    '16028': {
        requiredDraw: 75,
        rules: [{
            message: 'Cannot include more than 1 copy of each event (by title)',
            condition: function condition(deck) {
                var allCards = deck.drawCards.concat(deck.plotCards);
                var eventNames = allCards.filter(function (cardQuantity) {
                    return cardQuantity.card.type === 'event';
                }).map(function (cardQuantity) {
                    return cardQuantity.card.name;
                });
                return eventNames.every(function (eventName) {
                    return deck.countCards(function (card) {
                        return card.name === eventName;
                    }) <= 1;
                });
            }
        }]
    },
    // The Long Voyage
    '16030': {
        requiredDraw: 100
    },
    // Kingdom of Shadows (Redesign)
    '17148': {
        mayInclude: card => !card.loyal && (hasKeyword(card, /Shadow \(\d+\)/)||hasKeyword(card, /暗影\(\d+\)/))
    },
    // Sea of Blood (Redesign)
    '17149': {
        cannotInclude: function cannotInclude(card) {
            return card.faction === 'neutral' && card.type === 'event';
        }
    },
    // The Free Folk (Redesign)
    '17150': {
        mayInclude: card => card.faction !== 'neutral' && card.type === 'character' && !card.loyal && (hasTrait(card, 'Wildling')||hasTrait(card, '野人')),
        rules: [{
            message: 'Must only contain neutral cards or Non-loyal Wildling characters',
            condition: function condition(deck) {
                let drawDeckValid = !deck.drawCards.some(function (cardQuantity) {
                    return cardQuantity.card.faction !== 'neutral' && !(cardQuantity.card.type === 'character' && !cardQuantity.card.loyal && (hasTrait(cardQuantity.card, 'Wildling')||hasTrait(cardQuantity.card, '野人')));
                });
                let plotDeckValid = !deck.plotCards.some(function (cardQuantity) {
                    return cardQuantity.card.faction !== 'neutral';
                });
                return drawDeckValid && plotDeckValid;
            }
        }]
    },
    // The Wars To Come (Redesign)
    '17151': {
        requiredPlots: 10,
        maxDoubledPlots: 2
    },
    // Valyrian Steel (Redesign)
    '17152': {
        requiredDraw: 75,
        rules: [{
            message: 'Cannot include more than 1 copy of each attachment',
            condition: function condition(deck) {
                var allCards = deck.drawCards.concat(deck.plotCards);
                var attachments = allCards.filter(function (cardQuantity) {
                    return cardQuantity.card.type === 'attachment';
                });
                return attachments.every(function (attachment) {
                    return attachment.count <= 1;
                });
            }
        }]
    },
    // A Mummer's Farce
    '20051': {
        mayInclude: function mayInclude(card) {
            return card.type === 'character' && (hasTrait(card, 'Fool') || hasTrait(card, '弄臣')) && !card.loyal;
        }
    },
    // The Many-Faced God
    '20052': {
        cannotInclude: function cannotInclude(card) {
            return card.type === 'plot' && (hasTrait(card, 'Kingdom')||hasTrait(card, '王国'));
        }
    },
    // Battle of the Trident
    '21030': {
        requiredPlots: 10,
        rules: [{
            message: 'Battle of the Trident must contain exactly 10 Edict, Siege or War plots',
            condition: function condition(deck) {
                return deck.plotCards.every(function (cardQuantity) {
                    return hasTrait(cardQuantity.card, '法令') || hasTrait(cardQuantity.card, '围困') || hasTrait(cardQuantity.card, '战争') || hasTrait(cardQuantity.card, 'Edict') || hasTrait(cardQuantity.card, 'Siege') || hasTrait(cardQuantity.card, 'War');
                });
            }
        }]
    },
    // Draft Agendas
    // The Power of Wealth
    '00001': {
        mayInclude: function mayInclude() {
            return true;
        },
        rules: [{
            message: 'Cannot include cards from more than 1 outside faction',
            condition: function condition(deck) {
                var outOfFactionCards = deck.drawCards.concat(deck.plotCards).filter(function (cardQuantity) {
                    return cardQuantity.card.faction !== deck.faction.value && cardQuantity.card.faction !== 'neutral';
                });
                var factions = new Set(outOfFactionCards.map(function (cardQuantity) {
                    return cardQuantity.card.faction;
                }));
                return factions.size <= 1;
            }
        }]
    },
    // Protectors of the Realm
    '00002': {
        mayInclude: function mayInclude(card) {
            return card.type === 'character' && (hasTrait(card, 'Knight') || hasTrait(card, 'Army') || hasTrait(card, '骑士') || hasTrait(card, '军队'));
        }
    },
    // Treaty
    '00003': {
        mayInclude: function mayInclude() {
            return true;
        },
        rules: [{
            message: 'Cannot include cards from more than 2 outside factions',
            condition: function condition(deck) {
                var outOfFactionCards = deck.drawCards.concat(deck.plotCards).filter(function (cardQuantity) {
                    return cardQuantity.card.faction !== deck.faction.value && cardQuantity.card.faction !== 'neutral';
                });
                var factions = new Set(outOfFactionCards.map(function (cardQuantity) {
                    return cardQuantity.card.faction;
                }));
                return factions.size <= 2;
            }
        }]
    },
    // Uniting the Seven Kingdoms
    '00004': {
        mayInclude: function mayInclude(card) {
            return card.type !== 'plot';
        }
    }
};

module.exports = agendaRules;
